==> SSOAP_0.2-2.tar.gz: SSOAP/man/genSOAPClientInterface.Rd <==
\name{genSOAPClientInterface}
\alias{genSOAPClientInterface}
\title{Create R functions to access SOAP server methods}
\description{
  This function creates function definitions, etc. that provide
  access to the methods described in the SOAP server description
  details.  
}
\usage{
genSOAPClientInterface(operations = def@operations[[1]], def, name, env = new.env(), where = 1, verbose = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{operations}{a list of the descriptions of the server's methods. Each method description 
     provides information about the parameters and the return value.}
  \item{def}{the \code{\link{SOAPServerDescription-class}} object.}
  \item{name}{currently unused }
  \item{env}{an environment object.  This is used ?}
  \item{where}{the location (usually in the search path) where new S4 classes will 
    be defined to represent the complex return types.  This can be any value that is acceptable for the
    \code{where} argument of \code{\link[methods]{setClass}}, i.e. 
     an integer, a package name (\dQuote{package:name}) or, explicitly, an environment.  }
  \item{verbose}{a logical indicating whether information about the processing should be displayed on the console,
       as it occurs.}
}
\details{

}
\value{
}

\references{
  \url{http://www.w3.org/TR/SOAP/}
  \url{http://www.omegahat.org/SSOAP},
  \url{http://www.omegahat.org/bugs}.
}
\author{Duncan Temple Lang <duncan@wald.ucdavis.edu>}


\seealso{
 \code{\link{processWSDL}}
 }
\examples{

}
\keyword{interface}
\keyword{programming}

==> SSOAP_0.4-1.tar.gz: SSOAP/man/genSOAPClientInterface.Rd <==
\name{genSOAPClientInterface}
\alias{genSOAPClientInterface}
\title{Create R functions to access SOAP server methods}
\description{
  This function creates function definitions, etc. that provide
  access to the methods described in the SOAP server description
  details.  
}
\usage{
genSOAPClientInterface(operations = def@operations[[1]], def, name,
                       env = new.env(), where = 1, server = def@server,
                       verbose = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{operations}{a list of the descriptions of the server's methods. Each method description 
     provides information about the parameters and the return value.}
  \item{def}{the \code{\link{SOAPServerDescription-class}} object.}
  \item{name}{currently unused }
  \item{env}{an environment object.  This is used ?}
  \item{where}{the location (usually in the search path) where new S4 classes will 
    be defined to represent the complex return types.  This can be any value that is acceptable for the
    \code{where} argument of \code{\link[methods]{setClass}}, i.e. 
     an integer, a package name (\dQuote{package:name}) or, explicitly, an environment.  }
   \item{server}{an object which will be used as the server in the SOAP
     calls. This provides the user with a mechanism to provide an
     alternative server object such as one which contains a password
     or which already has a connection to the SOAP server, or controls
     the connection in different ways.
   }
 \item{verbose}{a logical indicating whether information about the processing should be displayed on the console,
       as it occurs.}
}
\details{

}
\value{
}

\references{
  \url{http://www.w3.org/TR/SOAP/}
  \url{http://www.omegahat.org/SSOAP},
  \url{http://www.omegahat.org/bugs}.
}
\author{Duncan Temple Lang <duncan@wald.ucdavis.edu>}


\seealso{
 \code{\link{processWSDL}}
 }
\examples{

}
\keyword{interface}
\keyword{programming}
